# PyQt5 开发框架

简介：

采用pyqtSlot+QMutex+QThread+pyqtSignal研发的多线程使用框架。

安装方法：
```shell script
pip install -i https://test.pypi.org/simple/ PyQt5-comet --prefix="我的项目路径"
复制Lib\site-packages\PyLib和Lib\site-packages\main.p到项目根目录，即可开始使用。
```

需要支持模块：
```shell script
pip install pyqt5 -i https://pypi.tuna.tsinghua.edu.cn/simple
pip install pyqt5-tools -i https://pypi.tuna.tsinghua.edu.cn/simple
```
